==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/rbutton.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR,$rt);
settype($CONF['rbutton_nums'], "integer");
$sql = "SELECT id,url,img_url,alt FROM T_Random_Buttons " .
       "ORDER BY RAND() LIMIT $CONF[rbutton_nums]";
$rt = SqlQuery($sql);
if (mysql_num_rows($rt)) {
   $VAR['Content'] = "<center>";
   while ($A = mysql_fetch_array($rt)) {
      if (!preg_match('!^http!', $A['img_url'])) $A['img_url'] = "$CONF[G_URL]/$A[img_url]";
      if (empty($A['alt'])) $A['alt'] = $A['url'];
      $VAR['Content'] .= "<a href=\"$CONF[G_URL]/redirect.php?what=rbutton&amp;id=$A[id]".
                       "&amp;code=". KWL_HcodeMake("rbutton".$A['id'],1) ."\" target=\"_blank\">".
                       "<img src=\"$A[img_url]\" BORDER=\"0\" VSPACE=\"1\" HSPACE=\"1\" ALT=\"". KWL_PrepareHtml($A['alt']) ."\">".
                       "</a><BR>\n";
   }
   $VAR['Content'] .= "</center>";
   $VAR['Display'] =& $align;
   if (empty($CONF['rbutton_title'])) $VAR['Heading'] = _RANDOM_BUTTON;
   else $VAR['Heading'] = $CONF['rbutton_title'];
   KWL_DrawBlock($VAR);
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/rbutton.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR,$rt);
settype($CONF['rbutton_nums'], "integer");
$sql = "SELECT id,url,img_url,alt FROM T_Random_Buttons " .
       "ORDER BY RAND() LIMIT $CONF[rbutton_nums]";
$rt = SqlQuery($sql);
if (mysql_num_rows($rt)) {
   $VAR['Content'] = "<center>";
   while ($A = mysql_fetch_array($rt)) {
      if (!preg_match('!^http!', $A['img_url'])) $A['img_url'] = "$CONF[G_URL]/$A[img_url]";
      if (empty($A['alt'])) $A['alt'] = $A['url'];
      $VAR['Content'] .= "<a href=\"$CONF[G_URL]/redirect.php?what=rbutton&amp;id=$A[id]".
                       "&amp;code=". KWL_HcodeMake("rbutton".$A['id'],1) ."\" target=\"_blank\">".
                       "<img src=\"$A[img_url]\" border=\"0\" vspace=\"1\" hspace=\"1\" alt=\"". KWL_PrepareHtml($A['alt']) ."\" />".
                       "</a><br />\n";
   }
   $VAR['Content'] .= "</center>";
   $VAR['Display'] =& $align;
   if (empty($CONF['rbutton_title'])) $VAR['Heading'] = _RANDOM_BUTTON;
   else $VAR['Heading'] = $CONF['rbutton_title'];
   KWL_DrawBlock($VAR);
}
?>
